<?php

namespace Anytech\Trip\Http\Requests;

use App\Http\Requests\Request;
use User;

class TripsAdminRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(\Illuminate\Http\Request $request)
    {
        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return User::can('trip.trips.create');
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return User::can('trip.trips.edit');
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return User::can('trip.trips.delete');
        }

        // Determine if the user is authorized to view the module.
        return User::can('trip.trips.view');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(\Illuminate\Http\Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'trip_name'           => 'required',
                'trip_description'    => 'required',
                'featured_image'      => 'required',
            ];
        }

        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'trip_name'           => 'required',
                'trip_description'    => 'required',
                'featured_image'      => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
